@@ -1,9 +1,9 @@
 package Tapper::Benchmark;
-BEGIN {
-  $Tapper::Benchmark::AUTHORITY = 'cpan:TAPPER';
-}
+# git description: v0.012-2-g03356da
+
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$Tapper::Benchmark::VERSION = '0.012';
+$Tapper::Benchmark::VERSION = '5.0.0';
 use strict;
 use warnings;
 
@@ -732,7 +732,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -1320,7 +1320,7 @@ Roberto Schaefer <schaefr@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Amazon.com, Inc. or its affiliates.
+This software is Copyright (c) 2016 by Amazon.com, Inc. or its affiliates.
 
 This is free software, licensed under:
 
