@@ -1,9 +1,7 @@
 package Tapper::Benchmark::Query;
-BEGIN {
-  $Tapper::Benchmark::Query::AUTHORITY = 'cpan:TAPPER';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper::Benchmark - querying - base class
-$Tapper::Benchmark::Query::VERSION = '0.012';
+$Tapper::Benchmark::Query::VERSION = '5.0.0';
 use strict;
 use warnings;
 use Digest::MD5;
@@ -118,7 +116,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -130,7 +128,7 @@ Roberto Schaefer <schaefr@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Amazon.com, Inc. or its affiliates.
+This software is Copyright (c) 2016 by Amazon.com, Inc. or its affiliates.
 
 This is free software, licensed under:
 
